@@ -16,7 +16,11 @@ package gnu.jel;
 
 import gnu.jel.generated.EC;
 import gnu.jel.debug.Debug;
-import gnu.jel.reflect.*;
+import gnu.jel.reflect.Field;
+import gnu.jel.reflect.LocalField;
+import gnu.jel.reflect.Method;
+import gnu.jel.reflect.LocalMethod;
+import gnu.jel.reflect.Member;
 
 /**
  * This is the main front end to JEL.
