@@ -16,7 +16,11 @@ package gnu.jel;
 
 import gnu.jel.debug.Debug;
 import gnu.jel.debug.Tester;
-import gnu.jel.reflect.*;
+import gnu.jel.reflect.Field;
+import gnu.jel.reflect.LocalField;
+import gnu.jel.reflect.Method;
+import gnu.jel.reflect.LocalMethod;
+import gnu.jel.reflect.Member;
 import java.util.Hashtable;
 import java.util.Vector;
 import java.util.Enumeration;
