@@ -179,8 +179,22 @@ public class OPbinary extends OPfunction {
     this.code=code;
     int op2ID=typesStk.peekID();
     Class op2Type=typesStk.pop();
+    boolean unwrap2OP=false;
+    if (op2ID==8) {// try to unwrap second operand
+      int unwrapOP2ID=TypesStack.unwrapTypeID(op2Type);
+      unwrap2OP=(unwrapOP2ID>0);
+      if (unwrap2OP) op2ID=unwrapOP2ID;
+    };
+
     int op1ID=typesStk.peekID();
     Class op1Type=typesStk.pop();
+    boolean unwrap1OP=false;
+    if (op1ID==8) {// try to unwrap first operand
+      int unwrapOP1ID=TypesStack.unwrapTypeID(op1Type);
+      unwrap1OP=(unwrapOP1ID>0);
+      if (unwrap1OP) op1ID=unwrapOP1ID;
+    };
+
     OP p2CvtPlaceholder=(OP)paramOPs.pop();
     OP p1CvtPlaceholder=(OP)paramOPs.pop();
 
@@ -194,13 +208,13 @@ public class OPbinary extends OPfunction {
                                           " are incompatible for "+
                                           opNames[code]+" operation.");
         // insert conversion code
-        if (op1ID!=opsIDX) {
+        if ((op1ID!=opsIDX) || (unwrap1OP)) {
           typesStk.pushID(op1ID);
           list.addAfter(p1CvtPlaceholder,
                         new OPunary(typesStk,opsIDX,null,false));
           typesStk.pop();
         };
-        if (op2ID!=opsIDX) {
+        if ((op2ID!=opsIDX) || (unwrap2OP)) {
           typesStk.pushID(op2ID);
           list.addAfter(p2CvtPlaceholder,
                         new OPunary(typesStk,opsIDX,null,false));
@@ -251,7 +265,7 @@ public class OPbinary extends OPfunction {
                                           "array index of type "+op2Type+
                                           " to int.");
         // convert the index to int if needed
-        if (op2ID!=4) {
+        if ((op2ID!=4) || (unwrap2OP)) {
           typesStk.pushID(op2ID);
           list.addAfter(p2CvtPlaceholder,new OPunary(typesStk,4,null,false));
           typesStk.pop();
