@@ -31,16 +31,39 @@ public class TypesStack implements Cloneable {
   // string class
   protected static java.lang.Class string_class=null;
 
+  // interfaces to be automatically unwrapped
+  protected static Class[] unwrapClasses; 
+
   static {
     try {
       string_class=Class.forName("java.lang.String");
       tsb_class=Class.forName("gnu.jel.TempStringBuffer");
+
+      String[] unwrapClassNames={
+        "Boolean","Byte","Character","Short","Integer","Long","Float",
+        "Double"};
+      unwrapClasses=new Class[8];
+      for(int i=0;i<8;i++)
+        unwrapClasses[i]=
+          Class.forName("gnu.jel.reflect."+unwrapClassNames[i]);
     } catch (ClassNotFoundException exc) {
       if (Debug.enabled)
         Debug.reportThrowable(exc);
     };
   };
   
+  /**
+   * Identifies the type of the class for automatic reflection unwrapping
+   * @param cls class to unwrap
+   * @return primitive type ID or -1 if class can not be unwrapped.
+   */
+  public static int unwrapTypeID(Class cls) {
+    int resID=-1;
+    for(int i=0;(i<8)&&(resID==-1);i++)
+      if (unwrapClasses[i].isAssignableFrom(cls)) resID=i;
+    return resID;
+  };
+
   /**
    *  Classes of the primitive types by ID.
    */
@@ -296,7 +319,15 @@ public class TypesStack implements Cloneable {
     boolean pt2=t2.isPrimitive();
     
     if (pt2 && pt1) return isWidening(primitiveID(t1),primitiveID(t2));
-    if (pt2 ^  pt1) return false; // Can't convert yet between PT and OBJ.
+    if (pt2 ^  pt1) {
+      // try to unwrap
+      int unwrapID=unwrapTypeID(t1);
+      if (unwrapID>0) {
+        // OK, unwrapped, try to convert
+        return isWidening(unwrapID,primitiveID(t2));
+      };
+      return false; 
+    };
     // freely convert between string and tsb
     if (((t1==tsb_class) && (t2==string_class)) ||
         ((t2==tsb_class) && (t1==string_class))) return true;
