@@ -294,9 +294,10 @@ public class TestSuite {
 
     o.println(); o.println("----- DOT OPERATOR ------");
     // Construct a new library
-    Class[] dotLib=new Class[1];
+    Class[] dotLib=new Class[2];
     try {
       dotLib[0]=Class.forName("java.lang.String");
+      dotLib[1]=Class.forName("java.lang.Double");
     } catch(ClassNotFoundException e) {
       System.out.println(e);
       System.exit(1);
@@ -312,6 +313,16 @@ public class TestSuite {
 
     testError("\"abc\".nomethod()",null,lib,7,o);
     testError("\"abc\".length(666)",null,lib,7,o);
+    testError("2.0.doubleValue()",null,lib,5,o);
+    
+    testExpression("intObj+1", new Integer(556), null, rtp, lib,o);
+    testExpression("intObj", new Integer(555), null, rtp, lib,o);
+    testExpression("arr[intObj-554]", new Double(5.0), null, rtp, lib,o);
+    testExpression("arr[max(intObj-554,0)]", new Double(5.0), null, rtp, lib,o);
+    testExpression("arr[max(intObj,0)-554]", new Double(5.0), null, rtp, lib,o);
+
+    testExpression("arr[byteObj]", new Double(6.0), null, rtp, lib,o);
+    testExpression("byteObj+1.0", new Double(3.0), null, rtp, lib,o);
     
     o.println(); o.println("^^^^^^^^^^^^ SCORE success/failure = "+
                            successes+"/"+failures+
@@ -540,6 +551,13 @@ class OpenEvaluator extends Evaluator {
 
   public static CompiledExpression compile(OPlist list) {
 	byte[] image=Evaluator.getImage(list);
+    try {
+      java.io.FileOutputStream fos=new java.io.FileOutputStream("dump.class");
+      fos.write(image);
+      fos.close();
+    } catch (java.io.IOException exc) {
+      gnu.jel.debug.Debug.reportThrowable(exc);
+    };
 	try {
       return (CompiledExpression)(ImageLoader.load(image)).newInstance();
 	} catch (Exception exc) {
