@@ -1,4 +1,4 @@
-/*
+/*-*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
  * $Id: VariableProvider.java,v 1.4 1999/12/19 17:43:31 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
@@ -20,6 +20,10 @@ public class VariableProvider {
   public double x() {return xvar;};
 
   public double[] arr;
+  
+  public gnu.jel.reflect.Integer intObj;
+
+  public gnu.jel.reflect.Byte byteObj;
 
   public static final double[] arrs={1.0,2.0,3.0};
   
@@ -28,6 +32,8 @@ public class VariableProvider {
     arr[0]=4.0;
     arr[1]=5.0;
     arr[2]=6.0;
+    intObj=new IntegerObject(555);
+    byteObj=new ByteObject((byte)2);
   };
 
   public static int throw_arg_eq_4(int x) throws Exception {
@@ -53,3 +59,31 @@ public class VariableProvider {
 
 };
 
+class IntegerObject implements gnu.jel.reflect.Integer {
+  int val;
+  
+  public IntegerObject(int val) {
+	this.val=val;
+  };
+  
+  public int getValue() {
+	return val;
+  };;    
+};
+
+class ByteObject implements gnu.jel.reflect.Byte {
+  byte val;
+  
+  public ByteObject(byte val) {
+	this.val=val;
+  };
+  
+  public byte getValue() {
+	return val;
+  };;    
+};
+
+
+
+
+
